summaryrefslogtreecommitdiffstats
path: root/src/H5F.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/H5F.c')
-rw-r--r--src/H5F.c60
1 files changed, 30 insertions, 30 deletions
diff --git a/src/H5F.c b/src/H5F.c
index 574f512..2747912 100644
--- a/src/H5F.c
+++ b/src/H5F.c
@@ -235,7 +235,7 @@ H5F_init_interface(void)
H5P_genclass_t *mnt_pclass;
hbool_t local = H5F_MNT_SYM_LOCAL_DEF;
- FUNC_ENTER_NOINIT(H5F_init_interface)
+ FUNC_ENTER_NOAPI_NOINIT(H5F_init_interface)
#ifdef OLD_METADATA_WRITE
#ifdef H5_HAVE_PARALLEL
@@ -483,7 +483,7 @@ H5F_term_interface(void)
{
int n = 0;
- FUNC_ENTER_NOINIT(H5F_term_interface)
+ FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5F_term_interface)
if (interface_initialize_g) {
if ((n=H5I_nmembers(H5I_FILE))) {
@@ -672,7 +672,7 @@ H5F_flush_all_cb(void *_f, hid_t UNUSED fid, void *_invalidate)
H5F_t *f=(H5F_t *)_f;
unsigned invalidate = (*((hbool_t*)_invalidate);
- FUNC_ENTER_NOINIT(H5F_flush_all_cb)
+ FUNC_ENTER_NOAPI_NOINIT(H5F_flush_all_cb)
H5F_flush(f, H5F_SCOPE_LOCAL, (invalidate ? H5F_FLUSH_INVALIDATE : H5F_FLUSH_NONE));
@@ -964,7 +964,7 @@ H5F_get_obj_count(const H5F_t *f, unsigned types)
{
int ret_value; /* Return value */
- FUNC_ENTER_NOINIT(H5F_get_obj_count)
+ FUNC_ENTER_NOAPI_NOINIT(H5F_get_obj_count)
if((ret_value=H5F_get_objects(f, types, -1, NULL)) < 0)
HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "can't get counts of opened file IDs and object IDs in the file")
@@ -1029,7 +1029,7 @@ H5F_get_obj_ids(const H5F_t *f, unsigned types, int max_objs, hid_t *oid_list)
{
int ret_value; /* Return value */
- FUNC_ENTER_NOINIT(H5F_get_obj_ids)
+ FUNC_ENTER_NOAPI_NOINIT(H5F_get_obj_ids)
if((ret_value=H5F_get_objects(f, types, max_objs, oid_list)) < 0)
HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "can't get object IDs opened in the file")
@@ -1061,7 +1061,7 @@ H5F_get_objects(const H5F_t *f, unsigned types, int max_index, hid_t *obj_id_lis
H5F_olist_t olist; /* Structure to hold search results */
int ret_value; /* Return value */
- FUNC_ENTER_NOINIT(H5F_get_object)
+ FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5F_get_object)
/* Set up search information */
olist.obj_id_list = (max_index==0 ? NULL : obj_id_list);
@@ -1140,7 +1140,7 @@ H5F_get_objects_cb(void *obj_ptr, hid_t obj_id, void *key)
H5F_olist_t *olist = (H5F_olist_t *)key; /* Alias for search info */
int ret_value = FALSE; /* Return value */
- FUNC_ENTER_NOINIT(H5F_get_objects_cb)
+ FUNC_ENTER_NOAPI_NOINIT(H5F_get_objects_cb)
assert(obj_ptr);
assert(olist);
@@ -1269,7 +1269,7 @@ H5F_get_vfd_handle(const H5F_t *file, hid_t fapl, void**file_handle)
{
herr_t ret_value;
- FUNC_ENTER_NOINIT(H5F_get_vfd_handle)
+ FUNC_ENTER_NOAPI_NOINIT(H5F_get_vfd_handle)
assert(file_handle);
if((ret_value=H5FD_get_vfd_handle(file->shared->lf, fapl, file_handle)) < 0)
@@ -1305,7 +1305,7 @@ H5F_equal(void *_haystack, hid_t UNUSED id, void *_needle)
const H5FD_t *needle = (const H5FD_t*)_needle;
int retval;
- FUNC_ENTER_NOINIT(H5F_equal)
+ FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5F_equal)
retval = (0==H5FD_cmp(haystack->shared->lf, needle));
@@ -1340,7 +1340,7 @@ H5F_locate_signature(H5FD_t *file, hid_t dxpl_id)
unsigned n, maxpow;
haddr_t ret_value; /* Return value */
- FUNC_ENTER_NOINIT(H5F_locate_signature)
+ FUNC_ENTER_NOAPI_NOINIT(H5F_locate_signature)
/* Find the least N such that 2^N is larger than the file size */
if (HADDR_UNDEF==(addr=H5FD_get_eof(file)) ||
@@ -1466,7 +1466,7 @@ H5F_new(H5F_file_t *shared, hid_t fcpl_id, hid_t fapl_id)
int n;
H5P_genplist_t *plist; /* Property list */
- FUNC_ENTER_NOINIT(H5F_new)
+ FUNC_ENTER_NOAPI_NOINIT(H5F_new)
if (NULL==(f=H5FL_CALLOC(H5F_t)))
HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
@@ -1609,7 +1609,7 @@ H5F_dest(H5F_t *f, hid_t dxpl_id)
{
herr_t ret_value = SUCCEED;
- FUNC_ENTER_NOINIT(H5F_dest)
+ FUNC_ENTER_NOAPI_NOINIT(H5F_dest)
if (f && 1==f->nrefs) {
if (1==f->shared->nrefs) {
@@ -2977,7 +2977,7 @@ H5F_flush(H5F_t *f, hid_t dxpl_id, H5F_scope_t scope, unsigned flags)
unsigned i; /* Index variable */
herr_t ret_value; /* Return value */
- FUNC_ENTER_NOINIT(H5F_flush)
+ FUNC_ENTER_NOAPI_NOINIT(H5F_flush)
/* Sanity check arguments */
assert(f);
@@ -3460,7 +3460,7 @@ H5F_mount(H5G_entry_t *loc, const char *name, H5F_t *child,
H5RS_str_t *name_r; /* Ref-counted version of name */
herr_t ret_value = SUCCEED; /*return value */
- FUNC_ENTER_NOINIT(H5F_mount)
+ FUNC_ENTER_NOAPI_NOINIT(H5F_mount)
assert(loc);
assert(name && *name);
@@ -3583,7 +3583,7 @@ H5F_unmount(H5G_entry_t *loc, const char *name, hid_t dxpl_id)
unsigned lt, rt, md=0; /*binary search indices */
int cmp; /*binary search comparison value*/
- FUNC_ENTER_NOINIT(H5F_unmount)
+ FUNC_ENTER_NOAPI_NOINIT(H5F_unmount)
assert(loc);
assert(name && *name);
@@ -3977,8 +3977,8 @@ done:
unsigned
H5F_get_intent(const H5F_t *f)
{
- /* Use FUNC_ENTER_NOINIT here to avoid performance issues */
- FUNC_ENTER_NOINIT(H5F_get_intent)
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5F_get_intent)
assert(f);
@@ -4008,8 +4008,8 @@ H5F_get_intent(const H5F_t *f)
size_t
H5F_sizeof_addr(const H5F_t *f)
{
- /* Use FUNC_ENTER_NOINIT here to avoid performance issues */
- FUNC_ENTER_NOINIT(H5F_sizeof_addr)
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5F_sizeof_addr)
assert(f);
assert(f->shared);
@@ -4040,8 +4040,8 @@ H5F_sizeof_addr(const H5F_t *f)
size_t
H5F_sizeof_size(const H5F_t *f)
{
- /* Use FUNC_ENTER_NOINIT here to avoid performance issues */
- FUNC_ENTER_NOINIT(H5F_sizeof_size)
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5F_sizeof_size)
assert(f);
assert(f->shared);
@@ -4073,8 +4073,8 @@ H5F_sizeof_size(const H5F_t *f)
*/
unsigned H5F_sym_leaf_k(const H5F_t *f)
{
- /* Use FUNC_ENTER_NOINIT here to avoid performance issues */
- FUNC_ENTER_NOINIT(H5F_sym_leaf_k)
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5F_sym_leaf_k)
assert(f);
assert(f->shared);
@@ -4107,8 +4107,8 @@ unsigned H5F_sym_leaf_k(const H5F_t *f)
unsigned
H5F_Kvalue(const H5F_t *f, const H5B_class_t *type)
{
- /* Use FUNC_ENTER_NOINIT here to avoid performance issues */
- FUNC_ENTER_NOINIT(H5F_Kvalue)
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5F_Kvalue)
assert(f);
assert(f->shared);
@@ -4137,8 +4137,8 @@ H5F_Kvalue(const H5F_t *f, const H5B_class_t *type)
hid_t
H5F_get_driver_id(const H5F_t *f)
{
- /* Use FUNC_ENTER_NOINIT here to avoid performance issues */
- FUNC_ENTER_NOINIT(H5F_get_driver_id)
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5F_get_driver_id)
assert(f);
assert(f->shared);
@@ -4204,7 +4204,7 @@ H5F_get_id(H5F_t *file)
{
hid_t ret_value;
- FUNC_ENTER_NOINIT(H5F_get_id)
+ FUNC_ENTER_NOAPI_NOINIT(H5F_get_id)
assert(file);
@@ -4250,8 +4250,8 @@ done:
haddr_t
H5F_get_base_addr(const H5F_t *f)
{
- /* Use FUNC_ENTER_NOINIT here to avoid performance issues */
- FUNC_ENTER_NOINIT(H5F_get_base_addr)
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5F_get_base_addr)
assert(f);
assert(f->shared);